Environment class

Constructors

Environment(String production, String protocol, String apiroot, String host, String port, String context)
Environment.loadFromEnvFile()

Properties

apiroot → String
final
context → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
port → String
final
production → String
final
protocol → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApiUrl() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited