HttpRequest class

Implemented types

Constructors

HttpRequest(RequestClient client)

Properties

client ↔ RequestClient
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete<T>(String path, dynamic body, [HttpOptions? options]) → Future<Response>
override
get<T>(String path, [HttpOptions? options]) → Future<Response>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post<T>(String path, dynamic body, [HttpOptions? options]) → Future<Response>
override
put<T>(String path, dynamic body, [HttpOptions? options]) → Future<Response>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited