FileHelper class

Constructors

FileHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

dirPath ↔ Future<String>
getter/setter pair

Static Methods

copyFileToAppDir(String origin, String fileName) → Future<File>
createFileOnAppDir(String fileName, Uint8List fileBytes) → Future<File>
deleteFilesFromAppDir(String fileName) → Future<FileSystemEntity>
exists(String fileName) → Future<bool>
getAppDirFilePath(String fileName) → Future<String>
getAppDirFilePathSync(String appDirPath, String fileName) → String
getAppDirPath() → Future<String>
readFileFromAppDir(String fileName) → Future<File>