GoogleMapsResponse class

Implemented types

Constructors

GoogleMapsResponse()

Properties

hashCode → int
The hash code for this object.
no setterinherited
lat ↔ double
getter/setter pairoverride
lng ↔ double
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateView ↔ bool
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited