MapController class

Constructors

MapController()
MapController.seeded(MapResponse mapResponse)
factory

Properties

currentLocation ↔ BehaviorSubject<MapResponse>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tempLocation ↔ BehaviorSubject<MapResponse>
getter/setter pair

Methods

getCurrentLocation() → Future<MapResponse>
latLng({required double lat, required double lng, bool updateView = false}) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveLocation() → void
setCurrentLocation() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited