MapWidget class

Inheritance

Constructors

MapWidget({Key? key, required MapController? mapController, MapType mapType = MapType.google, double? width, double? height, dynamic onMapCreated()?, bool editable = true, String? buttonText, String? locationPinText, String? hintText})
const

Properties

buttonText → String?
final
editable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hintText → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locationPinText → String?
final
mapController → MapController?
final
mapType → MapType
final
onMapCreated → dynamic Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MapWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited