StepperController class

Constructors

StepperController()

Properties

currentStep → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → BehaviorSubject<StepChangeIntention>
no setter

Methods

goToStep(int index, {bool force = false, dynamic notify = true}) → void
isLastStep() → bool
next({bool force = false, dynamic notify = true}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onStepChange(void onData(StepChangeIntention value)?, {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<StepChangeIntention>
previous({bool force = false, dynamic notify = true}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited