Channel class

Constructors

Channel({required String host, required int port, required Handler handler, bool? ssl = false, bool reconnectOnClose = false, String? token, WebSocket? client, Timer? timer})

Properties

client ↔ WebSocket?
getter/setter pair
connector ↔ Function?
getter/setter pair
handler → Handler
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
isConnected ↔ BehaviorSubject<bool>
getter/setter pair
logger → LogManager
final
port → int
final
reconnectOnClose → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssl → bool?
final
timer ↔ Timer?
getter/setter pair
token → String?
final
uri → dynamic
no setter

Methods

initialize() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reconnect() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited