TVKHandler class

Implemented types

Constructors

TVKHandler()

Properties

channel ↔ Channel?
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
logger → LogManager
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConnect(WebSocket ws) → void
override
onData(dynamic data) → void
override
onDone() → void
override
onError(dynamic message) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited